from setuptools import setup

setup(name='tkg_utils',
      version='2.0.3',
      description='tkg_utils',
      url='https://github.com/BigDataFounder/tkg_utils',
      author='gengch',
      author_email='gengchuanhua@163.com',
      license='MIT',
      packages=['tkg_utils', "tkg_utils/Normal", "tkg_utils/SdkAdapter", "tkg_utils/Utils"])
